==> hs-gconf-0.12.1.1_1.tbz: lib/ghc-7.4.2/cabal/gconf-0.12.1.1/register.sh <==
#!/bin/sh
echo 'name: gconf
version: 0.12.1.1
id: gconf-0.12.1.1-a4726e39f596e2df657ca0e9e5788034

license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@lists.sourceforge.net
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
package-url:
synopsis: Binding to the GNOME configuration database system.
description: GConf is a configuration database system for storing application
             preferences. It supports default or mandatory settings set by the
             administrator, and changes to the database are instantly applied to all
             running applications. It is written for the GNOME desktop but doesn'\''t
             require it.
category: System
author: Duncan Coutts
exposed: True
exposed-modules: System.Gnome.GConf System.Gnome.GConf.GConfClient
hidden-modules: System.Gnome.GConf.GConfValue
                System.Gnome.GConf.Types System.Gnome.GConf.Signals
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.2/cabal/gconf-0.12.1.1
library-dirs: /usr/local/lib/ghc-7.4.2/cabal/gconf-0.12.1.1
              /usr/local/lib
hs-libraries: HSgconf-0.12.1.1
extra-libraries: gconf-2 glib-2.0
extra-ghci-libraries:
include-dirs: /usr/local/include /usr/local/include/gconf/2
              /usr/local/include/orbit-2.0 /usr/local/include/glib-2.0
includes:
depends: base-4.5.1.0-f58939ca866a8377999e7a71aa62d1d0
         glib-0.12.4-2696509aa1c1a77771da26d8647d44d8
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.2/cabal/gconf-0.12.1.1/html/gconf.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.2/cabal/gconf-0.12.1.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-gconf-0.12.1_3.tbz: lib/ghc-7.4.1/cabal/gconf-0.12.1/register.sh <==
#!/bin/sh
echo 'name: gconf
version: 0.12.1
id: gconf-0.12.1-de43813917f901426cfe36b90c4f0494

license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@lists.sourceforge.net
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
package-url:
synopsis: Binding to the GNOME configuration database system.
description: GConf is a configuration database system for storing application
             preferences. It supports default or mandatory settings set by the
             administrator, and changes to the database are instantly applied to all
             running applications. It is written for the GNOME desktop but doesn'\''t
             require it.
category: System
author: Duncan Coutts
exposed: True
exposed-modules: System.Gnome.GConf System.Gnome.GConf.GConfClient
hidden-modules: System.Gnome.GConf.GConfValue
                System.Gnome.GConf.Types System.Gnome.GConf.Signals
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.1/cabal/gconf-0.12.1
library-dirs: /usr/local/lib/ghc-7.4.1/cabal/gconf-0.12.1
              /usr/local/lib
hs-libraries: HSgconf-0.12.1
extra-libraries: gconf-2 glib-2.0
extra-ghci-libraries:
include-dirs: /usr/local/include /usr/local/include/gconf/2
              /usr/local/include/orbit-2.0 /usr/local/include/glib-2.0
includes:
depends: base-4.5.0.0-3459bca6d8e46666b517e8bb2e033728
         glib-0.12.3.1-b8fe1b8554ac9f9afc9af7e353ede55d
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.1/cabal/gconf-0.12.1/html/gconf.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.1/cabal/gconf-0.12.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
